@@ -54,7 +54,9 @@ public class RightTest {
 			String result = target.invoke("0000000123", args);
 			fail(result);
 		}
-		catch (Exception e) { }
+		catch (Exception e) {
+			System.out.println(e.getLocalizedMessage());
+		}
 	}
 
 	@Test
@@ -65,7 +67,9 @@ public class RightTest {
 			String result = target.invoke("0000000123", args);
 			fail(result);
 		}
-		catch (Exception e) { }
+		catch (Exception e) {
+			System.out.println(e.getLocalizedMessage());
+		}
 	}
 
 	@Test
@@ -76,7 +80,9 @@ public class RightTest {
 			String result = target.invoke("0000000123", args);
 			fail(result);
 		}
-		catch (Exception e) { }
+		catch (Exception e) {
+			System.out.println(e.getLocalizedMessage());
+		}
 	}
 	
 }
